@@ -1,20 +1,21 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public License
+ *  as published by the Free Software Foundation; either version 2.1
+ *  of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free
+ *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
+ *  02110-1301, USA.
  */
 
 
@@ -26,6 +27,19 @@
 
 #include "gmime-filter-best.h"
 
+
+/**
+ * SECTION: gmime-filter-best
+ * @title: GMimeFilterBest
+ * @short_description: Determine the best charset/encoding to use for a stream
+ * @see_also: #GMimeFilter
+ *
+ * A #GMimeFilter which is meant to determine the best charset and/or
+ * transfer encoding suitable for the stream which is filtered through
+ * it.
+ **/
+
+
 static void g_mime_filter_best_class_init (GMimeFilterBestClass *klass);
 static void g_mime_filter_best_init (GMimeFilterBest *filter, GMimeFilterBestClass *klass);
 static void g_mime_filter_best_finalize (GObject *object);
@@ -230,7 +244,7 @@ g_mime_filter_best_new (unsigned int flags)
 {
 	GMimeFilterBest *new;
 	
-	new = g_object_new (GMIME_TYPE_FILTER_BEST, NULL, NULL);
+	new = g_object_new (GMIME_TYPE_FILTER_BEST, NULL);
 	new->flags = flags;
 	filter_reset ((GMimeFilter *) new);
 	
@@ -274,44 +288,44 @@ g_mime_filter_best_charset (GMimeFilterBest *best)
  *
  * Returns the best encoding for the stream filtered by @best.
  **/
-GMimePartEncodingType
+GMimeContentEncoding
 g_mime_filter_best_encoding (GMimeFilterBest *best, GMimeBestEncoding required)
 {
-	GMimePartEncodingType encoding = GMIME_PART_ENCODING_DEFAULT;
+	GMimeContentEncoding encoding = GMIME_CONTENT_ENCODING_DEFAULT;
 	
-	g_return_val_if_fail (GMIME_IS_FILTER_BEST (best), GMIME_PART_ENCODING_DEFAULT);
+	g_return_val_if_fail (GMIME_IS_FILTER_BEST (best), GMIME_CONTENT_ENCODING_DEFAULT);
 	
 	if (!(best->flags & GMIME_FILTER_BEST_ENCODING))
-		return GMIME_PART_ENCODING_DEFAULT;
+		return GMIME_CONTENT_ENCODING_DEFAULT;
 	
 	switch (required) {
 	case GMIME_BEST_ENCODING_7BIT:
 		if (best->count0 > 0) {
-			encoding = GMIME_PART_ENCODING_BASE64;
+			encoding = GMIME_CONTENT_ENCODING_BASE64;
 		} else if (best->count8 > 0) {
 			if (best->count8 >= (best->total * 17 / 100))
-				encoding = GMIME_PART_ENCODING_BASE64;
+				encoding = GMIME_CONTENT_ENCODING_BASE64;
 			else
-				encoding = GMIME_PART_ENCODING_QUOTEDPRINTABLE;
+				encoding = GMIME_CONTENT_ENCODING_QUOTEDPRINTABLE;
 		} else if (best->maxline > 998) {
-			encoding = GMIME_PART_ENCODING_QUOTEDPRINTABLE;
+			encoding = GMIME_CONTENT_ENCODING_QUOTEDPRINTABLE;
 		}
 		break;
 	case GMIME_BEST_ENCODING_8BIT:
 		if (best->count0 > 0) {
-			encoding = GMIME_PART_ENCODING_BASE64;
+			encoding = GMIME_CONTENT_ENCODING_BASE64;
 		} else if (best->maxline > 998) {
-			encoding = GMIME_PART_ENCODING_QUOTEDPRINTABLE;
+			encoding = GMIME_CONTENT_ENCODING_QUOTEDPRINTABLE;
 		}
 		break;
 	case GMIME_BEST_ENCODING_BINARY:
 		if (best->count0 + best->count8 > 0)
-			encoding = GMIME_PART_ENCODING_BINARY;
+			encoding = GMIME_CONTENT_ENCODING_BINARY;
 		break;
 	}
 	
-	if (encoding == GMIME_PART_ENCODING_DEFAULT && best->hadfrom)
-		encoding = GMIME_PART_ENCODING_QUOTEDPRINTABLE;
+	if (encoding == GMIME_CONTENT_ENCODING_DEFAULT && best->hadfrom)
+		encoding = GMIME_CONTENT_ENCODING_QUOTEDPRINTABLE;
 	
 	return encoding;
 }
