@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -228,7 +228,7 @@ g_mime_multipart_signed_new (void)
 static void
 sign_prepare (GMimeObject *mime_part)
 {
-	GMimePartEncodingType encoding;
+	GMimeContentEncoding encoding;
 	GMimeObject *subpart;
 	
 	if (GMIME_IS_MULTIPART (mime_part)) {
@@ -249,11 +249,11 @@ sign_prepare (GMimeObject *mime_part)
 		subpart = GMIME_MESSAGE_PART (mime_part)->message->mime_part;
 		sign_prepare (subpart);
 	} else {
-		encoding = g_mime_part_get_encoding (GMIME_PART (mime_part));
+		encoding = g_mime_part_get_content_encoding (GMIME_PART (mime_part));
 		
-		if (encoding != GMIME_PART_ENCODING_BASE64)
-			g_mime_part_set_encoding (GMIME_PART (mime_part),
-						  GMIME_PART_ENCODING_QUOTEDPRINTABLE);
+		if (encoding != GMIME_CONTENT_ENCODING_BASE64)
+			g_mime_part_set_content_encoding (GMIME_PART (mime_part),
+							  GMIME_CONTENT_ENCODING_QUOTEDPRINTABLE);
 	}
 }
 
@@ -327,7 +327,7 @@ g_mime_multipart_signed_sign (GMimeMultipartSigned *mps, GMimeObject *content,
 	sigstream = g_mime_stream_mem_new ();
 	
 	/* sign the content stream */
-	if (g_mime_cipher_sign (ctx, userid, hash, filtered_stream, sigstream, err) == -1) {
+	if (g_mime_cipher_context_sign (ctx, userid, hash, filtered_stream, sigstream, err) == -1) {
 		g_object_unref (filtered_stream);
 		g_object_unref (sigstream);
 		g_object_unref (stream);
@@ -353,7 +353,7 @@ g_mime_multipart_signed_sign (GMimeMultipartSigned *mps, GMimeObject *content,
 	g_object_unref (wrapper);
 	
 	mps->protocol = g_strdup (ctx->sign_protocol);
-	mps->micalg = g_strdup (g_mime_cipher_hash_name (ctx, hash));
+	mps->micalg = g_strdup (g_mime_cipher_context_hash_name (ctx, hash));
 	
 	/* set the content-type of the signature part */
 	content_type = g_mime_content_type_new_from_string (mps->protocol);
@@ -363,8 +363,8 @@ g_mime_multipart_signed_sign (GMimeMultipartSigned *mps, GMimeObject *content,
 	 * the CipherContext class - maybe ::sign can take/output a
 	 * GMimePart instead. */
 	if (!g_ascii_strcasecmp (mps->protocol, "application/pkcs7-signature")) {
+		g_mime_part_set_content_encoding (GMIME_PART (signature), GMIME_CONTENT_ENCODING_BASE64);
 		g_mime_part_set_filename (GMIME_PART (signature), "smime.p7m");
-		g_mime_part_set_encoding (GMIME_PART (signature), GMIME_PART_ENCODING_BASE64);
 	}
 	
 	/* save the content and signature parts */
@@ -480,8 +480,8 @@ g_mime_multipart_signed_verify (GMimeMultipartSigned *mps, GMimeCipherContext *c
 	g_object_unref (wrapper);
 	
 	/* verify the signature */
-	hash = g_mime_cipher_hash_id (ctx, mps->micalg);
-	valid = g_mime_cipher_verify (ctx, hash, stream, sigstream, err);
+	hash = g_mime_cipher_context_hash_id (ctx, mps->micalg);
+	valid = g_mime_cipher_context_verify (ctx, hash, stream, sigstream, err);
 	
 	d(printf ("attempted to verify:\n----- BEGIN SIGNED PART -----\n%.*s----- END SIGNED PART -----\n",
 		  (int) GMIME_STREAM_MEM (stream)->buffer->len, GMIME_STREAM_MEM (stream)->buffer->data));
