@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -26,8 +26,7 @@
 #include <stdio.h>
 
 #include <gmime/gmime-object.h>
-#include <gmime/gmime-param.h>
-#include <gmime/gmime-disposition.h>
+#include <gmime/gmime-encodings.h>
 #include <gmime/gmime-data-wrapper.h>
 
 G_BEGIN_DECLS
@@ -45,8 +44,7 @@ typedef struct _GMimePartClass GMimePartClass;
 struct _GMimePart {
 	GMimeObject parent_object;
 	
-	GMimePartEncodingType encoding;
-	GMimeDisposition *disposition;
+	GMimeContentEncoding encoding;
 	char *content_description;
 	char *content_location;
 	char *content_md5;
@@ -83,41 +81,15 @@ const char *g_mime_part_get_content_md5 (GMimePart *mime_part);
 void g_mime_part_set_content_location (GMimePart *mime_part, const char *content_location);
 const char *g_mime_part_get_content_location (GMimePart *mime_part);
 
-void g_mime_part_set_content_type (GMimePart *mime_part, GMimeContentType *mime_type);
-const GMimeContentType *g_mime_part_get_content_type (GMimePart *mime_part);
-
-void g_mime_part_set_encoding (GMimePart *mime_part, GMimePartEncodingType encoding);
-GMimePartEncodingType g_mime_part_get_encoding (GMimePart *mime_part);
-const char *g_mime_part_encoding_to_string (GMimePartEncodingType encoding);
-GMimePartEncodingType g_mime_part_encoding_from_string (const char *encoding);
-
-void g_mime_part_set_content_disposition_object (GMimePart *mime_part, GMimeDisposition *disposition);
-void g_mime_part_set_content_disposition (GMimePart *mime_part, const char *disposition);
-const char *g_mime_part_get_content_disposition (GMimePart *mime_part);
-
-void g_mime_part_add_content_disposition_parameter (GMimePart *mime_part, const char *attribute,
-						    const char *value);
-const char *g_mime_part_get_content_disposition_parameter (GMimePart *mime_part, const char *attribute);
+void g_mime_part_set_content_encoding (GMimePart *mime_part, GMimeContentEncoding encoding);
+GMimeContentEncoding g_mime_part_get_content_encoding (GMimePart *mime_part);
 
 void g_mime_part_set_filename (GMimePart *mime_part, const char *filename);
 const char *g_mime_part_get_filename (const GMimePart *mime_part);
 
-#ifndef GMIME_DISABLE_DEPRECATED
-void g_mime_part_set_content_byte_array (GMimePart *mime_part, GByteArray *content);
-void g_mime_part_set_content (GMimePart *mime_part, const char *content, size_t len);
-void g_mime_part_set_pre_encoded_content (GMimePart *mime_part, const char *content,
-					  size_t len, GMimePartEncodingType encoding);
-const char *g_mime_part_get_content (const GMimePart *mime_part, size_t *len);
-#endif /* GMIME_DISABLE_DEPRECATED */
-
 void g_mime_part_set_content_object (GMimePart *mime_part, GMimeDataWrapper *content);
 GMimeDataWrapper *g_mime_part_get_content_object (const GMimePart *mime_part);
 
-#ifndef GMIME_DISABLE_DEPRECATED
-ssize_t g_mime_part_write_to_stream (GMimePart *mime_part, GMimeStream *stream);
-char *g_mime_part_to_string (GMimePart *mime_part);
-#endif /* GMIME_DISABLE_DEPRECATED */
-
 G_END_DECLS
 
 #endif /* __GMIME_PART_H__ */
